Crate safe_fork

source

Structs

Functions

  • Ensures the current process is single-threaded.
  • Fork the current process.
  • Fork the current process, and execute the provided closure within child process, and wait for it to complete.
  • Fork the current process, and execute the provided closure within child process.
  • Check if the current process is single-threaded.